Random Generators
=================

GeneratorExample
----------------
.. autoclass:: poisson_approval.GeneratorExample
    :members:

GeneratorProfileOrdinalUniform
------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalUniform
    :members:

GeneratorProfileOrdinalGridUniform
----------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalGridUniform
    :members:

GeneratorProfileOrdinalVariations
---------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalVariations
    :members:

GeneratorProfileHistogramUniform
--------------------------------
.. autoclass:: poisson_approval.GeneratorProfileHistogramUniform
    :members:

GeneratorStrategyOrdinalUniform
-------------------------------
.. autoclass:: poisson_approval.GeneratorStrategyOrdinalUniform
    :members:

GeneratorStrategyThresholdUniform
---------------------------------
.. autoclass:: poisson_approval.GeneratorStrategyThresholdUniform
    :members:

GeneratorTauVectorUniform
-------------------------
.. autoclass:: poisson_approval.GeneratorTauVectorUniform
    :members:

GeneratorTauVectorGridUniform
-----------------------------
.. autoclass:: poisson_approval.GeneratorTauVectorGridUniform
    :members:
